@@ -35,7 +35,6 @@
 #define NV_ESC_MODULE_RESET      (NV_IOCTL_BASE + 4)
 #define NV_ESC_ALLOC_OS_EVENT    (NV_IOCTL_BASE + 6)
 #define NV_ESC_FREE_OS_EVENT     (NV_IOCTL_BASE + 7)
-#define NV_ESC_POST_VBIOS        (NV_IOCTL_BASE + 8)
 #define NV_ESC_STATUS_CODE       (NV_IOCTL_BASE + 9)
 #define NV_ESC_CHECK_VERSION_STR (NV_IOCTL_BASE + 10)
 
@@ -80,16 +79,6 @@ typedef struct nv_ioctl_card_info
 #define NV_IOCTL_CARD_INFO     \
     __NV_IOWR(NV_ESC_CARD_INFO, NvU8[NV_MAX_DEVICES*sizeof(nv_ioctl_card_info_t)])
 
-
-typedef struct nv_ioctl_post_vbios
-{
-    NvU32 bus;
-    NvU32 slot;
-} nv_ioctl_post_vbios_t;
-
-/* notify resman which card is primary */
-#define NV_IOCTL_POST_VBIOS __NV_IOWR(NV_ESC_POST_VBIOS, nv_ioctl_post_vbios_t)
-
 #define SIM_ENV_GPU       0
 #define SIM_ENV_IKOS      1
 #define SIM_ENV_CSIM      2
@@ -224,8 +213,7 @@ typedef struct
 {
     char *node;
     char *name;
-    U032 *data;
-    BOOL  valid;
+    NvU32 *data;
 } nv_parm_t;
 
 #if defined(NVCPU_X86_64)
@@ -283,6 +271,8 @@ typedef struct
     U016 device_id;
     void *handle;
 
+    U032 pci_cfg_space[16];
+
     /* physical characteristics */
     nv_aperture_t bars[NV_GPU_NUM_BARS];
     nv_aperture_t *regs;
@@ -316,12 +306,10 @@ typedef struct
  */
 
 #define NV_FLAG_OPEN            0x0001
-#define NV_FLAG_NEEDS_POSTING   0x0002
-#define NV_FLAG_WAS_POSTED      0x0004
-#define NV_FLAG_CONTROL         0x0010
-#define NV_FLAG_HOTKEY_OCCURRED 0x0100
-#define NV_FLAG_MAP_REGS_EARLY  0x0200
-#define NV_FLAG_USE_BAR0_CFG    0x0400
+#define NV_FLAG_WAS_POSTED      0x0002
+#define NV_FLAG_CONTROL         0x0004
+#define NV_FLAG_MAP_REGS_EARLY  0x0008
+#define NV_FLAG_USE_BAR0_CFG    0x0010
 
 #define NV_PM_APM_SUSPEND       0x0001
 #define NV_PM_APM_RESUME        0x0002
@@ -468,7 +456,6 @@ void*  NV_API_CALL  nv_get_adapter_state         (U016, U016);
 void   NV_API_CALL  nv_lock_rm                   (nv_state_t *);
 void   NV_API_CALL  nv_unlock_rm                 (nv_state_t *);
 
-void   NV_API_CALL  nv_set_hotkey_occurred_flag  (void);
 void   NV_API_CALL  nv_set_dma_address_size      (nv_state_t *, U032 );
 
 RM_STATUS  NV_API_CALL  nv_alloc_pages           (nv_state_t *, U032, U032, U032, U032, NvU64 *, void **);
@@ -548,13 +535,13 @@ RM_STATUS  NV_API_CALL  rm_i2c_smbus_write_quick  (nv_stack_t *, nv_state_t *, v
 RM_STATUS  NV_API_CALL  rm_i2c_smbus_read_buffer  (nv_stack_t *, nv_state_t *, void *, U008, U008, U032, U008 *);
 RM_STATUS  NV_API_CALL  rm_i2c_smbus_write_buffer (nv_stack_t *, nv_state_t *, void *, U008, U008, U032, U008 *);
 
-void       NV_API_CALL  rm_check_pci_config_space (nv_stack_t *, nv_state_t *nv, BOOL, BOOL *);
+void       NV_API_CALL  rm_check_pci_config_space (nv_stack_t *, nv_state_t *nv, BOOL, BOOL, BOOL);
 
 RM_STATUS  NV_API_CALL  rm_i2c_remove_adapters    (nv_stack_t *, nv_state_t *);
 
 RM_STATUS  NV_API_CALL  rm_perform_version_check  (nv_stack_t *, nv_ioctl_rm_api_version_t *);
 
-RM_STATUS  NV_API_CALL  rm_system_event           (U032);
+RM_STATUS  NV_API_CALL  rm_system_event           (nv_stack_t *, U032);
 
 #define rm_disable_interrupts(sp) rm_set_interrupts((sp),FALSE)
 #define rm_enable_interrupts(sp)  rm_set_interrupts((sp),TRUE)
