@@ -21,6 +21,7 @@ int nvidia_pci_probe(device_t dev)
 {
     U016 device;
     char name[NV_DEVICE_NAME_LENGTH];
+    nv_stack_t *sp;
 
     if ((pci_get_class(dev) != PCIC_DISPLAY) ||
             ((pci_get_subclass(dev) != PCIS_DISPLAY_VGA) &&
@@ -29,16 +30,24 @@ int nvidia_pci_probe(device_t dev)
             ((device = pci_get_device(dev)) < 0x0020))
         return ENXIO;
 
-    if (rm_is_legacy_device(NULL, device, TRUE)) {
+    NV_UMA_ZONE_ALLOC_STACK(sp);
+    if (sp == NULL)
+        return ENOMEM;
+
+    if (rm_is_legacy_device(sp, device, TRUE)) {
+        NV_UMA_ZONE_FREE_STACK(sp);
         return ENXIO;
     }
-    
-    if (rm_get_device_name(NULL, NULL, device, NV_DEVICE_NAME_LENGTH, name)
+
+    if (rm_get_device_name(sp, NULL, device, NV_DEVICE_NAME_LENGTH, name)
             != RM_OK) {
         strcpy(name, "Unknown");
     }
 
+    NV_UMA_ZONE_FREE_STACK(sp);
+
     device_set_desc_copy(dev, name);
+
     return 0;
 }
 
@@ -83,7 +92,13 @@ fail:
     return status;
 }
 
-void nvidia_pci_check_config_space(device_t dev, BOOL do_the_bars)
+void nvidia_pci_check_config_space(
+    nv_stack_t *sp,
+    device_t dev,
+    BOOL check_the_bars,
+    BOOL acquire_semaphore,
+    BOOL may_block
+)
 {
     U032 BAR_low, BAR_high;
     U016 word, i;
@@ -91,7 +106,8 @@ void nvidia_pci_check_config_space(device_t dev, BOOL do_the_bars)
     nv_state_t *nv = sc->nv_state;
 
     if (nv->flags & NV_FLAG_USE_BAR0_CFG) {
-        rm_check_pci_config_space(NULL, nv, do_the_bars, NULL);
+        rm_check_pci_config_space(sp, nv, check_the_bars,
+            acquire_semaphore, may_block);
         return;
     }
 
@@ -103,7 +119,7 @@ void nvidia_pci_check_config_space(device_t dev, BOOL do_the_bars)
     if ((word & PCIM_CMD_MEMEN) == 0)
         pci_enable_io(dev, SYS_RES_MEMORY);
 
-    if (do_the_bars)
+    if (check_the_bars)
     {
         for (i = 0; i < NV_GPU_NUM_BARS; i++) {
             BAR_low = BAR_high = 0;
@@ -167,6 +183,7 @@ int nvidia_pci_attach(device_t dev)
     struct nvidia_softc *sc;
     U016 word, i, j;
     U032 BAR_low, req;
+    nv_stack_t *sp;
 
     if (device_get_unit(dev) >= NV_MAX_DEVICES) {
         device_printf(dev, "NVRM: maximum device number exceeded.\n");
@@ -216,6 +233,14 @@ int nvidia_pci_attach(device_t dev)
     sc->irq_rid = 0;
     sc->iop_rid = 0;
 
+    NV_UMA_ZONE_ALLOC_STACK(sp);
+    if (sp == NULL) {
+        free(sc->nv_state, M_NVIDIA);
+        return ENOMEM;
+    }
+
+    sc->attach_sp = sp;
+
     status = nvidia_alloc_hardware(dev);
     if (status) {
         device_printf(dev, "NVRM: NVIDIA hardware alloc failed.\n");
@@ -235,7 +260,7 @@ int nvidia_pci_attach(device_t dev)
         goto fail;
     }
 
-    if (!rm_init_private_state(NULL, sc->nv_state)) {
+    if (!rm_init_private_state(sp, sc->nv_state)) {
         nvidia_pci_teardown_intr(dev);
         device_printf(dev, "NVRM: rm_init_private_state() failed.\n");
         nvidia_detach(dev);
@@ -249,13 +274,19 @@ int nvidia_pci_attach(device_t dev)
 
 fail:
     nvidia_free_hardware(dev);
+
+    sc->attach_sp = NULL;
+    NV_UMA_ZONE_FREE_STACK(sp);
+
     free(sc->nv_state, M_NVIDIA);
+
     return status;
 }
 
 int nvidia_pci_detach(device_t dev)
 {
     int status;
+    nv_stack_t *sp;
     struct nvidia_softc *sc;
     nv_state_t *nv;
 
@@ -289,8 +320,14 @@ int nvidia_pci_detach(device_t dev)
         goto fail;
     }
 
-    rm_free_private_state(NULL, sc->nv_state);
+    sp = sc->attach_sp;
+
+    rm_free_private_state(sp, sc->nv_state);
     nvidia_free_hardware(dev);
+
+    sc->attach_sp = NULL;
+    NV_UMA_ZONE_FREE_STACK(sp);
+
     free(sc->nv_state, M_NVIDIA);
 
 fail:
